FlutterFileLoggerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterFileLoggerPlatform
Implementers

Constructors

FlutterFileLoggerPlatform()
Constructs a FlutterFileLoggerPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
flush() Future<void>
log(LogLevel level, String tag, String msg) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open([LogConfig config = const LogConfig()]) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterFileLoggerPlatform
The default instance of FlutterFileLoggerPlatform to use.
getter/setter pair